@@ -25,6 +25,7 @@
 #include <QTemporaryDir>
 #include <QTemporaryFile>
 
+#include <KIO/DeleteJob>
 #include <KIO/FileCopyJob>
 #include <KIO/ListJob>
 #include <KIO/MkpathJob>
@@ -171,7 +172,16 @@ QUrl ExportManager::tempVideoUrl()
 const QTemporaryDir *ExportManager::temporaryDir()
 {
     if (!m_tempDir) {
+        // Cleanup Spectacle's temp dirs after startup instead of while quitting.
+        const auto filters = QDir::Filter::Dirs | QDir::NoDotAndDotDot | QDir::CaseSensitive | QDir::NoSymLinks;
+        const auto oldDirs = QDir::temp().entryList({u"Spectacle.??????"_s}, filters);
+        QList<QUrl> oldUrls;
+        for (const auto &dir : oldDirs) {
+            oldUrls << QUrl::fromLocalFile(QDir::tempPath() + u'/' + dir);
+        }
+        KIO::del(oldUrls, KIO::HideProgressInfo)->start();
         m_tempDir = std::make_unique<QTemporaryDir>(QDir::tempPath() + u"/Spectacle.XXXXXX"_s);
+        m_tempDir->setAutoRemove(false);
     }
     return m_tempDir->isValid() ? m_tempDir.get() : nullptr;
 }
@@ -197,28 +207,26 @@ QString ExportManager::formattedFilename(const QString &nameTemplate) const
     if (!title.isEmpty()) {
         title.replace(u'/', u'_'); // POSIX doesn't allow "/" in filenames
     } else {
-        // Remove '%T' with separators around it
+        // Remove <title> with separators around it
         const auto wordSymbol = uR"(\p{L}\p{M}\p{N})"_s;
         const auto separator = u"([^%1]+)"_s.arg(wordSymbol);
-        const auto re = QRegularExpression(u"(.*?)(%1%T|%T%1)(.*?)"_s.arg(separator));
+        const auto re = QRegularExpression(u"(.*?)(%1<title>|<title>%1)(.*?)"_s.arg(separator));
         baseName.replace(re, uR"(\1\5)"_s);
     }
 
-    QString result = baseName.replace("%Y"_L1, timestamp.toString(u"yyyy"_s))
-                             .replace("%y"_L1, timestamp.toString(u"yy"_s))
-                             .replace("%M"_L1, timestamp.toString(u"MM"_s))
-                             .replace("%n"_L1, timestamp.toString(u"MMM"_s))
-                             .replace("%N"_L1, timestamp.toString(u"MMMM"_s))
-                             .replace("%D"_L1, timestamp.toString(u"dd"_s))
-                             .replace("%H"_L1, timestamp.toString(u"hh"_s))
-                             .replace("%m"_L1, timestamp.toString(u"mm"_s))
-                             .replace("%S"_L1, timestamp.toString(u"ss"_s))
-                             .replace("%t"_L1, timestamp.toString(u"t"_s))
-                             .replace("%T"_L1, title);
+    QString result = baseName;
+    // Date/Time
+    for (auto it = filenamePlaceholders.cbegin(); it != filenamePlaceholders.cend(); ++it) {
+        if (it->category == Placeholder::Date || it->category == Placeholder::Time) {
+            result.replace(it->plainKey, timestamp.toString(it->baseKey));
+        }
+    }
+    // Other
+    result.replace("<title>"_L1, title);
 
     // check if basename includes %[N]d token for sequential file numbering
     QRegularExpression paddingRE;
-    paddingRE.setPattern(u"%(\\d*)d"_s);
+    paddingRE.setPattern(u"<(#+)>"_s);
     QRegularExpressionMatchIterator it = paddingRE.globalMatch(result);
     if (it.hasNext()) {
         // strip any subdirectories from the template to construct the filename matching regex
@@ -231,7 +239,7 @@ QString ExportManager::formattedFilename(const QString &nameTemplate) const
             // determine padding value
             int paddedLength = 1;
             if (!paddingMatch.captured(1).isEmpty()) {
-                paddedLength = paddingMatch.captured(1).toInt();
+                paddedLength = paddingMatch.captured(1).length();
             }
             QString escapedMatch = QRegularExpression::escape(paddingMatch.captured());
             resultCopy.replace(escapedMatch, u"(\\d{%1,})"_s.arg(QString::number(paddedLength)));
@@ -257,7 +265,7 @@ QString ExportManager::formattedFilename(const QString &nameTemplate) const
             if (filteredFiles.length() > 0) {
                 // loop through filtered file names looking for highest number
                 for (const QString &filteredFile : filteredFiles) {
-                    int currentFileNumber = fileNumberRE.match(filteredFile).captured(1).toInt();
+                    int currentFileNumber = fileNumberRE.match(filteredFile).captured(1).length();
                     if (currentFileNumber > highestFileNumber) {
                         highestFileNumber = currentFileNumber;
                     }
@@ -268,7 +276,7 @@ QString ExportManager::formattedFilename(const QString &nameTemplate) const
         for (const auto &match : matches) {
             int paddedLength = 1;
             if (!match.captured(1).isEmpty()) {
-                paddedLength = match.captured(1).toInt();
+                paddedLength = match.captured(1).length();
             }
             const QString nextFileNumberPadded = QString::number(highestFileNumber + 1).rightJustified(paddedLength, u'0');
             result.replace(match.captured(), nextFileNumberPadded);
@@ -735,21 +743,40 @@ void ExportManager::doPrint(QPrinter *printer)
     painter.end();
 }
 
-const QMap<QString, KLocalizedString> ExportManager::filenamePlaceholders{
-    {u"%Y"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Year (4 digit)")},
-    {u"%y"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Year (2 digit)")},
-    {u"%M"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Month")},
-    {u"%n"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Month (localized short name)")},
-    {u"%N"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Month (localized long name)")},
-    {u"%D"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Day")},
-    {u"%H"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Hour")},
-    {u"%m"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Minute")},
-    {u"%S"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Second")},
-    {u"%t"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Timezone")},
-    {u"%T"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Window Title")},
-    {u"%d"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Sequential numbering")},
-    {u"%Nd"_s,
-     ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Sequential numbering, padded out to N digits")},
+const QList<ExportManager::Placeholder> ExportManager::filenamePlaceholders{
+    {Placeholder::Date, u"d"_s},
+    {Placeholder::Date, u"dd"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Day")},
+    {Placeholder::Date, u"ddd"_s},
+    {Placeholder::Date, u"dddd"_s},
+    {Placeholder::Date, u"M"_s},
+    {Placeholder::Date, u"MM"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Month")},
+    {Placeholder::Date, u"MMM"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Month (localized short name)")},
+    {Placeholder::Date, u"MMMM"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Month (localized long name)")},
+    {Placeholder::Date, u"yy"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Year (2 digit)")},
+    {Placeholder::Date, u"yyyy"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Year (4 digit)")},
+    {Placeholder::Time, u"H"_s},
+    {Placeholder::Time, u"HH"_s},
+    {Placeholder::Time, u"h"_s},
+    {Placeholder::Time, u"hh"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Hour")},
+    {Placeholder::Time, u"m"_s},
+    {Placeholder::Time, u"mm"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Minute")},
+    {Placeholder::Time, u"s"_s},
+    {Placeholder::Time, u"ss"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Second")},
+    {Placeholder::Time, u"z"_s},
+    {Placeholder::Time, u"zz"_s}, // same as `z`
+    {Placeholder::Time, u"zzz"_s},
+    {Placeholder::Time, u"AP"_s},
+    {Placeholder::Time, u"A"_s}, // same as `AP`
+    {Placeholder::Time, u"ap"_s},
+    {Placeholder::Time, u"a"_s}, // same as `ap`
+    {Placeholder::Time, u"Ap"_s},
+    {Placeholder::Time, u"aP"_s}, // same as `Ap`
+    {Placeholder::Time, u"t"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Timezone")},
+    {Placeholder::Time, u"tt"_s},
+    {Placeholder::Time, u"ttt"_s},
+    {Placeholder::Time, u"tttt"_s},
+    {Placeholder::Other, u"title"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Window Title")},
+    {Placeholder::Other, u"#"_s, ki18nc("A placeholder in the user configurable filename will replaced by the specified value", "Sequential numbering, padded by inserting additional '#' characters")},
 };
 
 #include "moc_ExportManager.cpp"
