@@ -74,7 +74,38 @@ public:
 
     const QTemporaryDir *temporaryDir();
 
-    static const QMap<QString, KLocalizedString> filenamePlaceholders;
+    struct Placeholder {
+        enum Category {
+            Date,
+            Time,
+            Other,
+        };
+
+        const Category category;
+        const QString baseKey;
+        const QString plainKey;
+        const QString htmlKey;
+        const KLocalizedString description;
+
+        // Placeholders with empty descriptions will not be visible in the config UI
+        Placeholder(Category category, const QString &key, const KLocalizedString &description)
+            : category(category)
+            , baseKey(key)
+            , plainKey(u"<" % key % u">")
+            , htmlKey(u"&lt;" % key % u"&gt;") // key -> <key> in HTML
+            , description(description)
+        {
+        }
+
+        Placeholder(Category category, const QString &key)
+            : category(category)
+            , baseKey(key)
+            , plainKey(u"<" % key % u">")
+        {
+        }
+    };
+
+    static const QList<Placeholder> filenamePlaceholders;
 
 Q_SIGNALS:
     void imageChanged();
