@@ -165,8 +165,13 @@ static QImage readImage(int fileDescriptor, const QVariantMap &metadata)
     }
 
     bool ok = false;
-    const qreal scale = metadata.value(u"scale"_s).toReal(&ok);
+    qreal scale = metadata.value(u"scale"_s).toReal(&ok);
     if (ok) {
+        // NOTE: KWin X11Output DPR is always 1. This is intentional.
+        // https://bugs.kde.org/show_bug.cgi?id=474778
+        if (KWindowSystem::isPlatformX11() && scale == 1) {
+            scale = qGuiApp->devicePixelRatio();
+        }
         result.setDevicePixelRatio(scale);
     }
 
