@@ -5,23 +5,27 @@
 
 #pragma once
 
-#include "Platform.h"
+#include "ImagePlatform.h"
 #include "VideoPlatform.h"
 
-class PlatformNull final : public Platform
+class ImagePlatformNull final : public ImagePlatform
 {
     Q_OBJECT
 
 public:
-    explicit PlatformNull(QObject *parent = nullptr);
-    ~PlatformNull() override = default;
+    explicit ImagePlatformNull(QObject *parent = nullptr);
+    ~ImagePlatformNull() override = default;
 
     GrabModes supportedGrabModes() const override final;
     ShutterModes supportedShutterModes() const override final;
 
 public Q_SLOTS:
 
-    void doGrab(Platform::ShutterMode shutterMode, Platform::GrabMode grabMode, bool includePointer, bool includeDecorations) override final;
+    void doGrab(ImagePlatform::ShutterMode shutterMode,
+                ImagePlatform::GrabMode grabMode,
+                bool includePointer,
+                bool includeDecorations,
+                bool includeShadow) override final;
 };
 
 class VideoPlatformNull final : public VideoPlatform
@@ -32,13 +36,10 @@ public:
     explicit VideoPlatformNull(QObject *parent = nullptr);
 
     RecordingModes supportedRecordingModes() const override;
-    void startRecording(const QString &path, RecordingMode recordingMode, const RecordingOption &option, bool includePointer) override;
+    Formats supportedFormats() const override;
+    void startRecording(const QUrl &fileUrl, RecordingMode recordingMode, const QVariant &option, bool includePointer) override;
     void finishRecording() override;
 
-    void setExtension(const QString &encoder) override;
-    QString extension() const override;
-    QStringList suggestedExtensions() const override;
-
 private:
-    QString m_path;
+    QUrl m_fileUrl;
 };
